@@ -162,7 +162,11 @@ color_combo_reposition_window (GtkhtmlColorCombo *combo)
 
 	gdk_window_get_origin (window, &x, &y);
 
+#if GTK_CHECK_VERSION(2,19,7)
+	if (!gtk_widget_get_has_window (GTK_WIDGET (combo))) {
+#else
 	if (GTK_WIDGET_NO_WINDOW (combo)) {
+#endif
 		x += GTK_WIDGET (combo)->allocation.x;
 		y += GTK_WIDGET (combo)->allocation.y;
 	}
@@ -276,7 +280,7 @@ color_combo_custom_clicked_cb (GtkhtmlColorCombo *combo)
 		GTK_COLOR_SELECTION_DIALOG (dialog));
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (combo));
 
-	if (GTK_WIDGET_TOPLEVEL (toplevel))
+	if (gtk_widget_is_toplevel (toplevel))
 		gtk_window_set_transient_for (
 			GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
 
@@ -318,7 +322,11 @@ color_combo_default_release_event_cb (GtkhtmlColorCombo *combo,
                                       GdkEventButton *event,
                                       GtkButton *button)
 {
-	if (GTK_WIDGET_STATE (button) != GTK_STATE_NORMAL)
+	GtkStateType state;
+
+	state = gtk_widget_get_state (GTK_WIDGET (button));
+
+	if (state != GTK_STATE_NORMAL)
 		gtk_button_clicked (button);
 
 	return FALSE;
@@ -371,7 +379,11 @@ color_combo_swatch_release_event_cb (GtkhtmlColorCombo *combo,
                                      GdkEventButton *event,
                                      GtkButton *button)
 {
-	if (GTK_WIDGET_STATE (button) != GTK_STATE_NORMAL)
+	GtkStateType state;
+
+	state = gtk_widget_get_state (GTK_WIDGET (button));
+
+	if (state != GTK_STATE_NORMAL)
 		gtk_button_clicked (button);
 
 	return FALSE;
@@ -620,7 +632,11 @@ color_combo_popup (GtkhtmlColorCombo *combo)
 	GdkGrabStatus status;
 	const gchar *label;
 
+#if GTK_CHECK_VERSION(2,19,7)
+	if (!gtk_widget_get_realized (GTK_WIDGET (combo)))
+#else
 	if (!GTK_WIDGET_REALIZED (combo))
+#endif
 		return;
 
 	if (combo->priv->popup_shown)
@@ -667,7 +683,11 @@ color_combo_popdown (GtkhtmlColorCombo *combo)
 {
 	GtkToggleButton *toggle_button;
 
+#if GTK_CHECK_VERSION(2,19,7)
+	if (!gtk_widget_get_realized (GTK_WIDGET (combo)))
+#else
 	if (!GTK_WIDGET_REALIZED (combo))
+#endif
 		return;
 
 	if (!combo->priv->popup_shown)
@@ -895,7 +915,7 @@ color_combo_init (GtkhtmlColorCombo *combo)
 	gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
 	gtk_window_set_type_hint (
 		GTK_WINDOW (window), GDK_WINDOW_TYPE_HINT_COMBO);
-	if (GTK_WIDGET_TOPLEVEL (toplevel)) {
+	if (gtk_widget_is_toplevel (toplevel)) {
 		gtk_window_group_add_window (
 			gtk_window_get_group (GTK_WINDOW (toplevel)),
 			GTK_WINDOW (window));
